@@ -39,11 +39,9 @@ def get_status(headers):
         if RE_STATUS.match(v.strip()):
             return v
 
-
 def get_notification(message):
     for part in message.walk():
-        if part.headers.get('Content-Description',
-                            '').lower() == 'notification':
+        if part.headers.get('Content-Description', '').lower() == 'notification':
             return part.body
 
 
@@ -58,7 +56,6 @@ HEADERS = ('Action',
 
 RE_STATUS = re.compile(r'\d\.\d+\.\d+', re.IGNORECASE)
 
-
 class Result(object):
     def __init__(self, score, status, notification, diagnostic_code):
         self.score = score
@@ -66,8 +63,4 @@ class Result(object):
         self.notification = notification
         self.diagnostic_code = diagnostic_code
 
-    def __repr__(self):
-        return (u'bounce.Result(status={}, score={}, notification={},'
-                u' diag_code={})'.format(self.status, self.score,
-                                         self.notification,
-                                         self.diagnostic_code))
+
